[PATCH] D34514: [mips] Enable IAS by default for Android 64-bit MIPS target (N64)

Petar Jovanovic via Phabricator via cfe-commits cfe-commits at lists.llvm.org
Thu Jun 22 07:30:29 PDT 2017


petarj created this revision.
Herald added subscribers: arichardson, srhines.

IAS is already used for MIPS64 in majority of Android projects.
Android MIPS64 uses N64 ABI. Set IAS as a default now.


Repository:
  rL LLVM

https://reviews.llvm.org/D34514

Files:
  lib/Driver/ToolChains/Gnu.cpp


Index: lib/Driver/ToolChains/Gnu.cpp
===================================================================
--- lib/Driver/ToolChains/Gnu.cpp
+++ lib/Driver/ToolChains/Gnu.cpp
@@ -2319,9 +2319,10 @@
     return true;
   case llvm::Triple::mips64:
   case llvm::Triple::mips64el:
-    // Enabled for Debian mips64/mips64el only. Other targets are unable to
-    // distinguish N32 from N64.
-    if (getTriple().getEnvironment() == llvm::Triple::GNUABI64)
+    // Enabled for Debian mips64/mips64el and Android (uses N64 ABI).
+    // Other targets are unable to distinguish N32 from N64.
+    if (getTriple().getEnvironment() == llvm::Triple::GNUABI64 ||
+        getTriple().isAndroid())
       return true;
     return false;
   default:


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D34514.103574.patch
Type: text/x-patch
Size: 737 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/cfe-commits/attachments/20170622/309d984e/attachment.bin>


More information about the cfe-commits mailing list